# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent']

@pulumi.input_type
class NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs:
    def __init__(__self__, *,
                 destination_resource_id: pulumi.Input[_builtins.str],
                 ip_traffic: pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs'],
                 source_resource_id: pulumi.Input[_builtins.str],
                 verifier_workspace_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent resource.

        :param pulumi.Input[_builtins.str] destination_resource_id: The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs'] ip_traffic: An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] source_resource_id: The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] verifier_workspace_id: The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] description: The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        pulumi.set(__self__, "ip_traffic", ip_traffic)
        pulumi.set(__self__, "source_resource_id", source_resource_id)
        pulumi.set(__self__, "verifier_workspace_id", verifier_workspace_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "destination_resource_id", value)

    @_builtins.property
    @pulumi.getter(name="ipTraffic")
    def ip_traffic(self) -> pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs']:
        """
        An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "ip_traffic")

    @ip_traffic.setter
    def ip_traffic(self, value: pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs']):
        pulumi.set(self, "ip_traffic", value)

    @_builtins.property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "source_resource_id")

    @source_resource_id.setter
    def source_resource_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_resource_id", value)

    @_builtins.property
    @pulumi.getter(name="verifierWorkspaceId")
    def verifier_workspace_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "verifier_workspace_id")

    @verifier_workspace_id.setter
    def verifier_workspace_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "verifier_workspace_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_traffic: Optional[pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 verifier_workspace_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent resources.

        :param pulumi.Input[_builtins.str] description: The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] destination_resource_id: The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs'] ip_traffic: An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] source_resource_id: The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] verifier_workspace_id: The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_resource_id is not None:
            pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        if ip_traffic is not None:
            pulumi.set(__self__, "ip_traffic", ip_traffic)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if source_resource_id is not None:
            pulumi.set(__self__, "source_resource_id", source_resource_id)
        if verifier_workspace_id is not None:
            pulumi.set(__self__, "verifier_workspace_id", verifier_workspace_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_resource_id", value)

    @_builtins.property
    @pulumi.getter(name="ipTraffic")
    def ip_traffic(self) -> Optional[pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs']]:
        """
        An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "ip_traffic")

    @ip_traffic.setter
    def ip_traffic(self, value: Optional[pulumi.Input['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs']]):
        pulumi.set(self, "ip_traffic", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "source_resource_id")

    @source_resource_id.setter
    def source_resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_resource_id", value)

    @_builtins.property
    @pulumi.getter(name="verifierWorkspaceId")
    def verifier_workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "verifier_workspace_id")

    @verifier_workspace_id.setter
    def verifier_workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "verifier_workspace_id", value)


@pulumi.type_token("azure:network/networkManagerVerifierWorkspaceReachabilityAnalysisIntent:NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent")
class NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_traffic: Optional[pulumi.Input[Union['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 verifier_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Network Manager Verifier Workspace Reachability Analysis Intent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_subscription()
        example_network_manager = azure.network.NetworkManager("example",
            name="example-nm",
            resource_group_name=example.name,
            location=example.location,
            scope={
                "subscription_ids": [current.id],
            },
            scope_accesses=["Connectivity"])
        example_network_manager_verifier_workspace = azure.network.NetworkManagerVerifierWorkspace("example",
            name="example",
            network_manager_id=example_network_manager.id,
            location=example.location)
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="internal",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_network_interface = azure.network.NetworkInterface("example",
            name="example-nic",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "internal",
                "subnet_id": example_subnet.id,
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_B1ls",
            admin_username="adminuser",
            admin_password="P@ssw0rd1234!",
            disable_password_authentication=False,
            network_interface_ids=[example_network_interface.id],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            },
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            })
        example_network_manager_verifier_workspace_reachability_analysis_intent = azure.network.NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent("example",
            name="example-intent",
            verifier_workspace_id=example_network_manager_verifier_workspace.id,
            source_resource_id=example_linux_virtual_machine.id,
            destination_resource_id=example_linux_virtual_machine.id,
            description="example",
            ip_traffic={
                "source_ips": ["10.0.2.1"],
                "source_ports": ["80"],
                "destination_ips": ["10.0.2.2"],
                "destination_ports": ["*"],
                "protocols": ["Any"],
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Network` - 2025-01-01

        ## Import

        Network Manager Verifier Workspace Reachability Analysis Intents can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:network/networkManagerVerifierWorkspaceReachabilityAnalysisIntent:NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Network/networkManagers/manager1/verifierWorkspaces/workspace1/reachabilityAnalysisIntents/intent1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] destination_resource_id: The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[Union['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgsDict']] ip_traffic: An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] source_resource_id: The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] verifier_workspace_id: The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Network Manager Verifier Workspace Reachability Analysis Intent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_subscription()
        example_network_manager = azure.network.NetworkManager("example",
            name="example-nm",
            resource_group_name=example.name,
            location=example.location,
            scope={
                "subscription_ids": [current.id],
            },
            scope_accesses=["Connectivity"])
        example_network_manager_verifier_workspace = azure.network.NetworkManagerVerifierWorkspace("example",
            name="example",
            network_manager_id=example_network_manager.id,
            location=example.location)
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="internal",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_network_interface = azure.network.NetworkInterface("example",
            name="example-nic",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "internal",
                "subnet_id": example_subnet.id,
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_B1ls",
            admin_username="adminuser",
            admin_password="P@ssw0rd1234!",
            disable_password_authentication=False,
            network_interface_ids=[example_network_interface.id],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            },
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            })
        example_network_manager_verifier_workspace_reachability_analysis_intent = azure.network.NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent("example",
            name="example-intent",
            verifier_workspace_id=example_network_manager_verifier_workspace.id,
            source_resource_id=example_linux_virtual_machine.id,
            destination_resource_id=example_linux_virtual_machine.id,
            description="example",
            ip_traffic={
                "source_ips": ["10.0.2.1"],
                "source_ports": ["80"],
                "destination_ips": ["10.0.2.2"],
                "destination_ports": ["*"],
                "protocols": ["Any"],
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Network` - 2025-01-01

        ## Import

        Network Manager Verifier Workspace Reachability Analysis Intents can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:network/networkManagerVerifierWorkspaceReachabilityAnalysisIntent:NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Network/networkManagers/manager1/verifierWorkspaces/workspace1/reachabilityAnalysisIntents/intent1
        ```


        :param str resource_name: The name of the resource.
        :param NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_traffic: Optional[pulumi.Input[Union['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 verifier_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs.__new__(NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentArgs)

            __props__.__dict__["description"] = description
            if destination_resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_resource_id'")
            __props__.__dict__["destination_resource_id"] = destination_resource_id
            if ip_traffic is None and not opts.urn:
                raise TypeError("Missing required property 'ip_traffic'")
            __props__.__dict__["ip_traffic"] = ip_traffic
            __props__.__dict__["name"] = name
            if source_resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_resource_id'")
            __props__.__dict__["source_resource_id"] = source_resource_id
            if verifier_workspace_id is None and not opts.urn:
                raise TypeError("Missing required property 'verifier_workspace_id'")
            __props__.__dict__["verifier_workspace_id"] = verifier_workspace_id
        super(NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent, __self__).__init__(
            'azure:network/networkManagerVerifierWorkspaceReachabilityAnalysisIntent:NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            destination_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
            ip_traffic: Optional[pulumi.Input[Union['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            source_resource_id: Optional[pulumi.Input[_builtins.str]] = None,
            verifier_workspace_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent':
        """
        Get an existing NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] destination_resource_id: The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[Union['NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgs', 'NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTrafficArgsDict']] ip_traffic: An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] source_resource_id: The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        :param pulumi.Input[_builtins.str] verifier_workspace_id: The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentState.__new__(_NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_resource_id"] = destination_resource_id
        __props__.__dict__["ip_traffic"] = ip_traffic
        __props__.__dict__["name"] = name
        __props__.__dict__["source_resource_id"] = source_resource_id
        __props__.__dict__["verifier_workspace_id"] = verifier_workspace_id
        return NetworkManagerVerifierWorkspaceReachabilityAnalysisIntent(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the resource. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the destination resource. The value can be the ID of either Public internet, Cosmos DB, Storage Account, SQL Server, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "destination_resource_id")

    @_builtins.property
    @pulumi.getter(name="ipTraffic")
    def ip_traffic(self) -> pulumi.Output['outputs.NetworkManagerVerifierWorkspaceReachabilityAnalysisIntentIpTraffic']:
        """
        An `ip_traffic` block as defined below. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "ip_traffic")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Network Manager Verifier Workspace Reachability Analysis Intent. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the source resource. The value can be the ID of either Public internet, Virtual machines, or Subnet. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "source_resource_id")

    @_builtins.property
    @pulumi.getter(name="verifierWorkspaceId")
    def verifier_workspace_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Network Manager Verifier Workspace. Changing this forces a new Network Manager Verifier Workspace Reachability Analysis Intent to be created.
        """
        return pulumi.get(self, "verifier_workspace_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkManagerRoutingRuleArgs', 'NetworkManagerRoutingRule']

@pulumi.input_type
class NetworkManagerRoutingRuleArgs:
    def __init__(__self__, *,
                 destination: pulumi.Input['NetworkManagerRoutingRuleDestinationArgs'],
                 next_hop: pulumi.Input['NetworkManagerRoutingRuleNextHopArgs'],
                 rule_collection_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a NetworkManagerRoutingRule resource.

        :param pulumi.Input['NetworkManagerRoutingRuleDestinationArgs'] destination: A `destination` block as defined below.
        :param pulumi.Input['NetworkManagerRoutingRuleNextHopArgs'] next_hop: A `next_hop` block as defined below.
        :param pulumi.Input[_builtins.str] rule_collection_id: The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] description: A description for the routing rule.
        :param pulumi.Input[_builtins.str] name: The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "destination", destination)
        pulumi.set(__self__, "next_hop", next_hop)
        pulumi.set(__self__, "rule_collection_id", rule_collection_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> pulumi.Input['NetworkManagerRoutingRuleDestinationArgs']:
        """
        A `destination` block as defined below.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input['NetworkManagerRoutingRuleDestinationArgs']):
        pulumi.set(self, "destination", value)

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> pulumi.Input['NetworkManagerRoutingRuleNextHopArgs']:
        """
        A `next_hop` block as defined below.
        """
        return pulumi.get(self, "next_hop")

    @next_hop.setter
    def next_hop(self, value: pulumi.Input['NetworkManagerRoutingRuleNextHopArgs']):
        pulumi.set(self, "next_hop", value)

    @_builtins.property
    @pulumi.getter(name="ruleCollectionId")
    def rule_collection_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "rule_collection_id")

    @rule_collection_id.setter
    def rule_collection_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rule_collection_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the routing rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NetworkManagerRoutingRuleState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input['NetworkManagerRoutingRuleDestinationArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input['NetworkManagerRoutingRuleNextHopArgs']] = None,
                 rule_collection_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetworkManagerRoutingRule resources.

        :param pulumi.Input[_builtins.str] description: A description for the routing rule.
        :param pulumi.Input['NetworkManagerRoutingRuleDestinationArgs'] destination: A `destination` block as defined below.
        :param pulumi.Input[_builtins.str] name: The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        :param pulumi.Input['NetworkManagerRoutingRuleNextHopArgs'] next_hop: A `next_hop` block as defined below.
        :param pulumi.Input[_builtins.str] rule_collection_id: The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if next_hop is not None:
            pulumi.set(__self__, "next_hop", next_hop)
        if rule_collection_id is not None:
            pulumi.set(__self__, "rule_collection_id", rule_collection_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the routing rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input['NetworkManagerRoutingRuleDestinationArgs']]:
        """
        A `destination` block as defined below.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input['NetworkManagerRoutingRuleDestinationArgs']]):
        pulumi.set(self, "destination", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> Optional[pulumi.Input['NetworkManagerRoutingRuleNextHopArgs']]:
        """
        A `next_hop` block as defined below.
        """
        return pulumi.get(self, "next_hop")

    @next_hop.setter
    def next_hop(self, value: Optional[pulumi.Input['NetworkManagerRoutingRuleNextHopArgs']]):
        pulumi.set(self, "next_hop", value)

    @_builtins.property
    @pulumi.getter(name="ruleCollectionId")
    def rule_collection_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "rule_collection_id")

    @rule_collection_id.setter
    def rule_collection_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_collection_id", value)


@pulumi.type_token("azure:network/networkManagerRoutingRule:NetworkManagerRoutingRule")
class NetworkManagerRoutingRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleDestinationArgs', 'NetworkManagerRoutingRuleDestinationArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleNextHopArgs', 'NetworkManagerRoutingRuleNextHopArgsDict']]] = None,
                 rule_collection_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Network Manager Routing Rule.

        !> **Note:** Terraform has enabled force deletion. This setting deletes the resource even if it's part of a deployed configuration. If the configuration is deployed, the service will perform a cleanup deployment in the background before the deletion.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_subscription()
        example_network_manager = azure.network.NetworkManager("example",
            name="example-network-manager",
            resource_group_name=example.name,
            location=example.location,
            scope={
                "subscription_ids": [current.id],
            },
            scope_accesses=["Routing"])
        example_network_manager_network_group = azure.network.NetworkManagerNetworkGroup("example",
            name="example-network-group",
            network_manager_id=example_network_manager.id)
        example_network_manager_routing_configuration = azure.network.NetworkManagerRoutingConfiguration("example",
            name="example-routing-configuration",
            network_manager_id=example_network_manager.id)
        example_network_manager_routing_rule_collection = azure.network.NetworkManagerRoutingRuleCollection("example",
            name="example-routing-rule-collection",
            routing_configuration_id=example_network_manager_routing_configuration.id,
            network_group_ids=[example_network_manager_network_group.id],
            description="example routing rule collection")
        example_network_manager_routing_rule = azure.network.NetworkManagerRoutingRule("example",
            name="example-routing-rule",
            rule_collection_id=example_network_manager_routing_rule_collection.id,
            description="example routing rule",
            destination={
                "type": "AddressPrefix",
                "address": "10.0.0.0/24",
            },
            next_hop={
                "type": "VirtualNetworkGateway",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Network` - 2025-01-01

        ## Import

        Network Manager Routing Rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:network/networkManagerRoutingRule:NetworkManagerRoutingRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Network/networkManagers/manager1/routingConfigurations/conf1/ruleCollections/collection1/rules/rule1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description for the routing rule.
        :param pulumi.Input[Union['NetworkManagerRoutingRuleDestinationArgs', 'NetworkManagerRoutingRuleDestinationArgsDict']] destination: A `destination` block as defined below.
        :param pulumi.Input[_builtins.str] name: The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['NetworkManagerRoutingRuleNextHopArgs', 'NetworkManagerRoutingRuleNextHopArgsDict']] next_hop: A `next_hop` block as defined below.
        :param pulumi.Input[_builtins.str] rule_collection_id: The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkManagerRoutingRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Network Manager Routing Rule.

        !> **Note:** Terraform has enabled force deletion. This setting deletes the resource even if it's part of a deployed configuration. If the configuration is deployed, the service will perform a cleanup deployment in the background before the deletion.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        current = azure.core.get_subscription()
        example_network_manager = azure.network.NetworkManager("example",
            name="example-network-manager",
            resource_group_name=example.name,
            location=example.location,
            scope={
                "subscription_ids": [current.id],
            },
            scope_accesses=["Routing"])
        example_network_manager_network_group = azure.network.NetworkManagerNetworkGroup("example",
            name="example-network-group",
            network_manager_id=example_network_manager.id)
        example_network_manager_routing_configuration = azure.network.NetworkManagerRoutingConfiguration("example",
            name="example-routing-configuration",
            network_manager_id=example_network_manager.id)
        example_network_manager_routing_rule_collection = azure.network.NetworkManagerRoutingRuleCollection("example",
            name="example-routing-rule-collection",
            routing_configuration_id=example_network_manager_routing_configuration.id,
            network_group_ids=[example_network_manager_network_group.id],
            description="example routing rule collection")
        example_network_manager_routing_rule = azure.network.NetworkManagerRoutingRule("example",
            name="example-routing-rule",
            rule_collection_id=example_network_manager_routing_rule_collection.id,
            description="example routing rule",
            destination={
                "type": "AddressPrefix",
                "address": "10.0.0.0/24",
            },
            next_hop={
                "type": "VirtualNetworkGateway",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Network` - 2025-01-01

        ## Import

        Network Manager Routing Rules can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:network/networkManagerRoutingRule:NetworkManagerRoutingRule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Network/networkManagers/manager1/routingConfigurations/conf1/ruleCollections/collection1/rules/rule1
        ```


        :param str resource_name: The name of the resource.
        :param NetworkManagerRoutingRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkManagerRoutingRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleDestinationArgs', 'NetworkManagerRoutingRuleDestinationArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 next_hop: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleNextHopArgs', 'NetworkManagerRoutingRuleNextHopArgsDict']]] = None,
                 rule_collection_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkManagerRoutingRuleArgs.__new__(NetworkManagerRoutingRuleArgs)

            __props__.__dict__["description"] = description
            if destination is None and not opts.urn:
                raise TypeError("Missing required property 'destination'")
            __props__.__dict__["destination"] = destination
            __props__.__dict__["name"] = name
            if next_hop is None and not opts.urn:
                raise TypeError("Missing required property 'next_hop'")
            __props__.__dict__["next_hop"] = next_hop
            if rule_collection_id is None and not opts.urn:
                raise TypeError("Missing required property 'rule_collection_id'")
            __props__.__dict__["rule_collection_id"] = rule_collection_id
        super(NetworkManagerRoutingRule, __self__).__init__(
            'azure:network/networkManagerRoutingRule:NetworkManagerRoutingRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            destination: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleDestinationArgs', 'NetworkManagerRoutingRuleDestinationArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            next_hop: Optional[pulumi.Input[Union['NetworkManagerRoutingRuleNextHopArgs', 'NetworkManagerRoutingRuleNextHopArgsDict']]] = None,
            rule_collection_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'NetworkManagerRoutingRule':
        """
        Get an existing NetworkManagerRoutingRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description for the routing rule.
        :param pulumi.Input[Union['NetworkManagerRoutingRuleDestinationArgs', 'NetworkManagerRoutingRuleDestinationArgsDict']] destination: A `destination` block as defined below.
        :param pulumi.Input[_builtins.str] name: The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['NetworkManagerRoutingRuleNextHopArgs', 'NetworkManagerRoutingRuleNextHopArgsDict']] next_hop: A `next_hop` block as defined below.
        :param pulumi.Input[_builtins.str] rule_collection_id: The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkManagerRoutingRuleState.__new__(_NetworkManagerRoutingRuleState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination"] = destination
        __props__.__dict__["name"] = name
        __props__.__dict__["next_hop"] = next_hop
        __props__.__dict__["rule_collection_id"] = rule_collection_id
        return NetworkManagerRoutingRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A description for the routing rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def destination(self) -> pulumi.Output['outputs.NetworkManagerRoutingRuleDestination']:
        """
        A `destination` block as defined below.
        """
        return pulumi.get(self, "destination")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Network Manager Routing Rule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> pulumi.Output['outputs.NetworkManagerRoutingRuleNextHop']:
        """
        A `next_hop` block as defined below.
        """
        return pulumi.get(self, "next_hop")

    @_builtins.property
    @pulumi.getter(name="ruleCollectionId")
    def rule_collection_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Network Manager Routing Rule Collection to which this rule belongs. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "rule_collection_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ManagedRedisCustomerManagedKeyArgs',
    'ManagedRedisCustomerManagedKeyArgsDict',
    'ManagedRedisDefaultDatabaseArgs',
    'ManagedRedisDefaultDatabaseArgsDict',
    'ManagedRedisDefaultDatabaseModuleArgs',
    'ManagedRedisDefaultDatabaseModuleArgsDict',
    'ManagedRedisIdentityArgs',
    'ManagedRedisIdentityArgsDict',
]

class ManagedRedisCustomerManagedKeyArgsDict(TypedDict):
    key_vault_key_id: pulumi.Input[_builtins.str]
    """
    The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name/a1b2c3d4`.
    """
    user_assigned_identity_id: pulumi.Input[_builtins.str]
    """
    The ID of the User Assigned Identity that has access to the Key Vault Key.
    """

@pulumi.input_type
class ManagedRedisCustomerManagedKeyArgs:
    def __init__(__self__, *,
                 key_vault_key_id: pulumi.Input[_builtins.str],
                 user_assigned_identity_id: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] key_vault_key_id: The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name/a1b2c3d4`.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        pulumi.set(__self__, "key_vault_key_id", key_vault_key_id)
        pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name/a1b2c3d4`.
        """
        return pulumi.get(self, "key_vault_key_id")

    @key_vault_key_id.setter
    def key_vault_key_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key_vault_key_id", value)

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_assigned_identity_id", value)


class ManagedRedisDefaultDatabaseArgsDict(TypedDict):
    access_keys_authentication_enabled: NotRequired[pulumi.Input[_builtins.bool]]
    """
    Whether access key authentication is enabled for the database. Defaults to `false`.
    """
    client_protocol: NotRequired[pulumi.Input[_builtins.str]]
    """
    Specifies whether redis clients can connect using TLS-encrypted or plaintext redis protocols. Possible values are `Encrypted` and `Plaintext`. Defaults to `Encrypted`.
    """
    clustering_policy: NotRequired[pulumi.Input[_builtins.str]]
    """
    Clustering policy specified at create time. Possible values are `EnterpriseCluster`, `OSSCluster` and `NoCluster`. Defaults to `OSSCluster`.

    !> **Note:** Changing `clustering_policy` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
    """
    eviction_policy: NotRequired[pulumi.Input[_builtins.str]]
    """
    Specifies the Redis eviction policy. Possible values are `AllKeysLFU`, `AllKeysLRU`, `AllKeysRandom`, `VolatileLRU`, `VolatileLFU`, `VolatileTTL`, `VolatileRandom` and `NoEviction`. Defaults to `VolatileLRU`.
    """
    geo_replication_group_name: NotRequired[pulumi.Input[_builtins.str]]
    """
    The name of the geo-replication group. If provided, a geo-replication group will be created for this database with itself as the only member. Use `azurerm_managed_redis_database_geo_replication` resource to manage group membership, linking and unlinking. All databases to be linked have to have the same group name. Refer to the [Managed Redis geo-replication documentation](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication) for more information.

    !> **Note:** Changing `geo_replication_group_name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
    """
    id: NotRequired[pulumi.Input[_builtins.str]]
    """
    The ID of the Managed Redis Database Instance.
    """
    modules: NotRequired[pulumi.Input[Sequence[pulumi.Input['ManagedRedisDefaultDatabaseModuleArgsDict']]]]
    """
    A `module` block as defined below. Refer to [the modules documentation](https://learn.microsoft.com/azure/redis/redis-modules) to learn more.
    """
    persistence_append_only_file_backup_frequency: NotRequired[pulumi.Input[_builtins.str]]
    """
    The frequency of Append Only File (AOF) backups. The only possible value is `1s`. Providing this value implies AOF persistence method is enabled. Conflicts with `persistence_redis_database_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
    """
    persistence_redis_database_backup_frequency: NotRequired[pulumi.Input[_builtins.str]]
    """
    The frequency of Redis Database (RDB) backups. Possible values are `1h`, `6h` and `12h`. Providing this value implies RDB persistence method is enabled. Conflicts with `persistence_append_only_file_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
    """
    port: NotRequired[pulumi.Input[_builtins.int]]
    """
    TCP port of the database endpoint.
    """
    primary_access_key: NotRequired[pulumi.Input[_builtins.str]]
    """
    The Primary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
    """
    secondary_access_key: NotRequired[pulumi.Input[_builtins.str]]
    """
    The Secondary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
    """

@pulumi.input_type
class ManagedRedisDefaultDatabaseArgs:
    def __init__(__self__, *,
                 access_keys_authentication_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 client_protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 clustering_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 eviction_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 geo_replication_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 modules: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedRedisDefaultDatabaseModuleArgs']]]] = None,
                 persistence_append_only_file_backup_frequency: Optional[pulumi.Input[_builtins.str]] = None,
                 persistence_redis_database_backup_frequency: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 primary_access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_access_key: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.bool] access_keys_authentication_enabled: Whether access key authentication is enabled for the database. Defaults to `false`.
        :param pulumi.Input[_builtins.str] client_protocol: Specifies whether redis clients can connect using TLS-encrypted or plaintext redis protocols. Possible values are `Encrypted` and `Plaintext`. Defaults to `Encrypted`.
        :param pulumi.Input[_builtins.str] clustering_policy: Clustering policy specified at create time. Possible values are `EnterpriseCluster`, `OSSCluster` and `NoCluster`. Defaults to `OSSCluster`.
               
               !> **Note:** Changing `clustering_policy` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param pulumi.Input[_builtins.str] eviction_policy: Specifies the Redis eviction policy. Possible values are `AllKeysLFU`, `AllKeysLRU`, `AllKeysRandom`, `VolatileLRU`, `VolatileLFU`, `VolatileTTL`, `VolatileRandom` and `NoEviction`. Defaults to `VolatileLRU`.
        :param pulumi.Input[_builtins.str] geo_replication_group_name: The name of the geo-replication group. If provided, a geo-replication group will be created for this database with itself as the only member. Use `azurerm_managed_redis_database_geo_replication` resource to manage group membership, linking and unlinking. All databases to be linked have to have the same group name. Refer to the [Managed Redis geo-replication documentation](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication) for more information.
               
               !> **Note:** Changing `geo_replication_group_name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param pulumi.Input[_builtins.str] id: The ID of the Managed Redis Database Instance.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedRedisDefaultDatabaseModuleArgs']]] modules: A `module` block as defined below. Refer to [the modules documentation](https://learn.microsoft.com/azure/redis/redis-modules) to learn more.
        :param pulumi.Input[_builtins.str] persistence_append_only_file_backup_frequency: The frequency of Append Only File (AOF) backups. The only possible value is `1s`. Providing this value implies AOF persistence method is enabled. Conflicts with `persistence_redis_database_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        :param pulumi.Input[_builtins.str] persistence_redis_database_backup_frequency: The frequency of Redis Database (RDB) backups. Possible values are `1h`, `6h` and `12h`. Providing this value implies RDB persistence method is enabled. Conflicts with `persistence_append_only_file_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        :param pulumi.Input[_builtins.int] port: TCP port of the database endpoint.
        :param pulumi.Input[_builtins.str] primary_access_key: The Primary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        :param pulumi.Input[_builtins.str] secondary_access_key: The Secondary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        if access_keys_authentication_enabled is not None:
            pulumi.set(__self__, "access_keys_authentication_enabled", access_keys_authentication_enabled)
        if client_protocol is not None:
            pulumi.set(__self__, "client_protocol", client_protocol)
        if clustering_policy is not None:
            pulumi.set(__self__, "clustering_policy", clustering_policy)
        if eviction_policy is not None:
            pulumi.set(__self__, "eviction_policy", eviction_policy)
        if geo_replication_group_name is not None:
            pulumi.set(__self__, "geo_replication_group_name", geo_replication_group_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if modules is not None:
            pulumi.set(__self__, "modules", modules)
        if persistence_append_only_file_backup_frequency is not None:
            pulumi.set(__self__, "persistence_append_only_file_backup_frequency", persistence_append_only_file_backup_frequency)
        if persistence_redis_database_backup_frequency is not None:
            pulumi.set(__self__, "persistence_redis_database_backup_frequency", persistence_redis_database_backup_frequency)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if primary_access_key is not None:
            pulumi.set(__self__, "primary_access_key", primary_access_key)
        if secondary_access_key is not None:
            pulumi.set(__self__, "secondary_access_key", secondary_access_key)

    @_builtins.property
    @pulumi.getter(name="accessKeysAuthenticationEnabled")
    def access_keys_authentication_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether access key authentication is enabled for the database. Defaults to `false`.
        """
        return pulumi.get(self, "access_keys_authentication_enabled")

    @access_keys_authentication_enabled.setter
    def access_keys_authentication_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "access_keys_authentication_enabled", value)

    @_builtins.property
    @pulumi.getter(name="clientProtocol")
    def client_protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether redis clients can connect using TLS-encrypted or plaintext redis protocols. Possible values are `Encrypted` and `Plaintext`. Defaults to `Encrypted`.
        """
        return pulumi.get(self, "client_protocol")

    @client_protocol.setter
    def client_protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_protocol", value)

    @_builtins.property
    @pulumi.getter(name="clusteringPolicy")
    def clustering_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Clustering policy specified at create time. Possible values are `EnterpriseCluster`, `OSSCluster` and `NoCluster`. Defaults to `OSSCluster`.

        !> **Note:** Changing `clustering_policy` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "clustering_policy")

    @clustering_policy.setter
    def clustering_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "clustering_policy", value)

    @_builtins.property
    @pulumi.getter(name="evictionPolicy")
    def eviction_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the Redis eviction policy. Possible values are `AllKeysLFU`, `AllKeysLRU`, `AllKeysRandom`, `VolatileLRU`, `VolatileLFU`, `VolatileTTL`, `VolatileRandom` and `NoEviction`. Defaults to `VolatileLRU`.
        """
        return pulumi.get(self, "eviction_policy")

    @eviction_policy.setter
    def eviction_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "eviction_policy", value)

    @_builtins.property
    @pulumi.getter(name="geoReplicationGroupName")
    def geo_replication_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the geo-replication group. If provided, a geo-replication group will be created for this database with itself as the only member. Use `azurerm_managed_redis_database_geo_replication` resource to manage group membership, linking and unlinking. All databases to be linked have to have the same group name. Refer to the [Managed Redis geo-replication documentation](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication) for more information.

        !> **Note:** Changing `geo_replication_group_name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "geo_replication_group_name")

    @geo_replication_group_name.setter
    def geo_replication_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "geo_replication_group_name", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Managed Redis Database Instance.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def modules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedRedisDefaultDatabaseModuleArgs']]]]:
        """
        A `module` block as defined below. Refer to [the modules documentation](https://learn.microsoft.com/azure/redis/redis-modules) to learn more.
        """
        return pulumi.get(self, "modules")

    @modules.setter
    def modules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedRedisDefaultDatabaseModuleArgs']]]]):
        pulumi.set(self, "modules", value)

    @_builtins.property
    @pulumi.getter(name="persistenceAppendOnlyFileBackupFrequency")
    def persistence_append_only_file_backup_frequency(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The frequency of Append Only File (AOF) backups. The only possible value is `1s`. Providing this value implies AOF persistence method is enabled. Conflicts with `persistence_redis_database_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        """
        return pulumi.get(self, "persistence_append_only_file_backup_frequency")

    @persistence_append_only_file_backup_frequency.setter
    def persistence_append_only_file_backup_frequency(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "persistence_append_only_file_backup_frequency", value)

    @_builtins.property
    @pulumi.getter(name="persistenceRedisDatabaseBackupFrequency")
    def persistence_redis_database_backup_frequency(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The frequency of Redis Database (RDB) backups. Possible values are `1h`, `6h` and `12h`. Providing this value implies RDB persistence method is enabled. Conflicts with `persistence_append_only_file_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        """
        return pulumi.get(self, "persistence_redis_database_backup_frequency")

    @persistence_redis_database_backup_frequency.setter
    def persistence_redis_database_backup_frequency(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "persistence_redis_database_backup_frequency", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        TCP port of the database endpoint.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Primary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        return pulumi.get(self, "primary_access_key")

    @primary_access_key.setter
    def primary_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_access_key", value)

    @_builtins.property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Secondary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        return pulumi.get(self, "secondary_access_key")

    @secondary_access_key.setter
    def secondary_access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_access_key", value)


class ManagedRedisDefaultDatabaseModuleArgsDict(TypedDict):
    name: pulumi.Input[_builtins.str]
    """
    The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`.

    !> **Note:** Changing `name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
    """
    args: NotRequired[pulumi.Input[_builtins.str]]
    """
    Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`).

    !> **Note:** Changing `args` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.

    > **Note:** Only `RediSearch` and `RedisJSON` modules are allowed with geo-replication.
    """
    version: NotRequired[pulumi.Input[_builtins.str]]
    """
    Version of the module to be used.
    """

@pulumi.input_type
class ManagedRedisDefaultDatabaseModuleArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 args: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] name: The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`.
               
               !> **Note:** Changing `name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param pulumi.Input[_builtins.str] args: Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`).
               
               !> **Note:** Changing `args` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
               
               > **Note:** Only `RediSearch` and `RedisJSON` modules are allowed with geo-replication.
        :param pulumi.Input[_builtins.str] version: Version of the module to be used.
        """
        pulumi.set(__self__, "name", name)
        if args is not None:
            pulumi.set(__self__, "args", args)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`.

        !> **Note:** Changing `name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`).

        !> **Note:** Changing `args` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.

        > **Note:** Only `RediSearch` and `RedisJSON` modules are allowed with geo-replication.
        """
        return pulumi.get(self, "args")

    @args.setter
    def args(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "args", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version of the module to be used.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


class ManagedRedisIdentityArgsDict(TypedDict):
    type: pulumi.Input[_builtins.str]
    """
    Specifies the type of Managed Service Identity that should be configured on this Managed Redis instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
    """
    identity_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
    """
    Specifies a list of User Assigned Managed Identity IDs to be assigned to this Managed Redis instance.

    > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
    """
    principal_id: NotRequired[pulumi.Input[_builtins.str]]
    tenant_id: NotRequired[pulumi.Input[_builtins.str]]

@pulumi.input_type
class ManagedRedisIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] type: Specifies the type of Managed Service Identity that should be configured on this Managed Redis instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Managed Redis instance.
               
               > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this Managed Redis instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Managed Redis instance.

        > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "identity_ids", value)

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "principal_id", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


